==> healthrian_ble_interface-1.1.40.tar.gz: lib/src/blue/flutter_blue_plus_wrapper.dart <==
import 'package:flutter_blue_plus/flutter_blue_plus.dart';

class FlutterBluePlusWrapper {
  LogLevel get logLevel => FlutterBluePlus.logLevel;

  Future<bool> get isAvailable => FlutterBluePlus.isAvailable;

  Future<String> get adapterName => FlutterBluePlus.adapterName;

  Stream<bool> get isScanning => FlutterBluePlus.isScanning;

  bool get isScanningNow => FlutterBluePlus.isScanningNow;

  Future<void> turnOn({int timeout = 10}) =>
      FlutterBluePlus.turnOn(timeout: timeout);

  Stream<List<ScanResult>> get scanResults => FlutterBluePlus.scanResults;

  Stream<BluetoothAdapterState> get adapterState =>
      FlutterBluePlus.adapterState;

  Future<List<BluetoothDevice>> get connectedSystemDevices =>
      FlutterBluePlus.connectedSystemDevices;

  Future<List<BluetoothDevice>> get bondedDevices =>
      FlutterBluePlus.bondedDevices;

  Stream<ScanResult> scan({
    ScanMode scanMode = ScanMode.lowLatency,
    List<Guid> withServices = const [],
    List<String> macAddresses = const [],
    Duration? timeout,
    bool allowDuplicates = false,
    bool androidUsesFineLocation = false,
  }) =>
      FlutterBluePlus.scan(
        timeout: timeout,
        scanMode: scanMode,
        withServices: withServices,
        allowDuplicates: allowDuplicates,
        androidUsesFineLocation: androidUsesFineLocation,
        macAddresses: macAddresses,
      );

  Future startScan({
    ScanMode scanMode = ScanMode.lowLatency,
    List<Guid> withServices = const [],
    List<String> macAddresses = const [],
    Duration? timeout,
    bool allowDuplicates = false,
    bool androidUsesFineLocation = false,
  }) =>
      FlutterBluePlus.startScan(
        scanMode: scanMode,
        withServices: withServices,
        macAddresses: macAddresses,
        timeout: timeout,
        androidUsesFineLocation: androidUsesFineLocation,
        allowDuplicates: allowDuplicates,
      );

  Future stopScan() => FlutterBluePlus.stopScan();

  void setLogLevel(LogLevel level, {color = true}) =>
      FlutterBluePlus.setLogLevel(level, color: color);

  @Deprecated('Use connectedSystemDevices instead')
  Future<List<BluetoothDevice>> get connectedDevices => connectedSystemDevices;
}

==> healthrian_ble_interface-1.2.1.tar.gz: lib/src/blue/flutter_blue_plus_wrapper.dart <==
import 'package:flutter_blue_plus/flutter_blue_plus.dart';

class FlutterBluePlusWrapper {
  LogLevel get logLevel => FlutterBluePlus.logLevel;

  Future<bool> get isAvailable => FlutterBluePlus.isAvailable;

  Future<String> get adapterName => FlutterBluePlus.adapterName;

  Stream<bool> get isScanning => FlutterBluePlus.isScanning;

  bool get isScanningNow => FlutterBluePlus.isScanningNow;

  Future<void> turnOn({int timeout = 10}) =>
      FlutterBluePlus.turnOn(timeout: timeout);

  Stream<List<ScanResult>> get scanResults => FlutterBluePlus.scanResults;

  Stream<BluetoothAdapterState> get adapterState =>
      FlutterBluePlus.adapterState;

  Future<List<BluetoothDevice>> get connectedSystemDevices =>
      FlutterBluePlus.connectedSystemDevices;

  Future<List<BluetoothDevice>> get bondedDevices =>
      FlutterBluePlus.bondedDevices;

  Stream<ScanResult> scan({
    ScanMode scanMode = ScanMode.lowLatency,
    List<Guid> withServices = const [],
    List<String> macAddresses = const [],
    Duration? timeout,
    bool allowDuplicates = false,
    bool androidUsesFineLocation = false,
  }) =>
      FlutterBluePlus.scan(
        timeout: timeout,
        scanMode: scanMode,
        withServices: withServices,
        allowDuplicates: allowDuplicates,
        androidUsesFineLocation: androidUsesFineLocation,
        macAddresses: macAddresses,
      );

  Future startScan({
    ScanMode scanMode = ScanMode.lowLatency,
    List<Guid> withServices = const [],
    List<String> macAddresses = const [],
    Duration? timeout,
    bool allowDuplicates = false,
    bool androidUsesFineLocation = false,
  }) =>
      FlutterBluePlus.startScan(
        scanMode: scanMode,
        withServices: withServices,
        macAddresses: macAddresses,
        timeout: timeout,
        androidUsesFineLocation: androidUsesFineLocation,
        allowDuplicates: allowDuplicates,
      );

  Future stopScan() => FlutterBluePlus.stopScan();

  void setLogLevel(LogLevel level, {color = true}) =>
      FlutterBluePlus.setLogLevel(level);

  @Deprecated('Use connectedSystemDevices instead')
  Future<List<BluetoothDevice>> get connectedDevices => connectedSystemDevices;
}
